Version

Struct Version 

pub struct Version(pub String);
Unique and opaque string, indicating the last affiliation version sent by the server that the client has seen, and cached.

Tuple Fields

0: String