pub struct Version(pub String);Expand description
Unique and opaque string, indicating the last affiliation version sent by the server that the client has seen, and cached.
Tuple Fields
0: StringTrait Implementations
Sourceimpl AsXmlText for Version
impl AsXmlText for Version
Sourceimpl FromXmlText for Version
impl FromXmlText for Version
Sourceimpl IntoAttributeValue for Version
impl IntoAttributeValue for Version
Sourcefn into_attribute_value(self) -> Option<String>
fn into_attribute_value(self) -> Option<String>
Turns this into an attribute string, or None if it shouldn’t be added.
impl Eq for Version
impl StructuralPartialEq for Version